@@ -9,11 +9,11 @@
 #' @author Maintainer: Leo Lahti \email{leo.lahti@@iki.fi}
 #' @examples \dontrun{d <- SotkanetData(indicator, years, genders)}
 #' @keywords utilities
-SotkanetData <- function(indicator, years, genders)
+SotkanetData <- function(indicator = 165, years = 2015:2016, genders = "total")
 {
 
   # Here the older url is in use for some reason:
-  url <- 'http://www.sotkanet.fi/rest/1.0/data/csv?'
+  url <- 'https://www.sotkanet.fi/rest/1.0/data/csv?'
   url <- paste(url, 'indicator=',indicator, '&years=', 
       	 	    paste(years, collapse='&years='), 
 		    '&genders=', paste(genders, 
